@@ -13,29 +13,29 @@ from Bio.Seq import Seq
 from .config import CSCConfig
 
 REGIONS = {
-    # The important ones the system asks for
-    "N439K": "NC_045512:22877-22879",
-    "Y453F": "NC_045512:22919-22921",
-    "E484K": "NC_045512:23012-23014",
-    "N501Y": "NC_045512:23063-23065",
-    "P681H": "NC_045512:23603-23605",
-    # Bonus mutations to help call variants
     "K417N": "NC_045512:22811-22813",
+    "K417T": "NC_045512:22811-22813",
+    "N439K": "NC_045512:22877-22879",
     "L452R": "NC_045512:22916-22918",
+    "Y453F": "NC_045512:22919-22921",
     "S477N": "NC_045512:22991-22993",
     "T478K": "NC_045512:22994-22996",
     "T478R": "NC_045512:22994-22996",
+    "E484K": "NC_045512:23012-23014",
     "E484Q": "NC_045512:23012-23014",
+    "N501Y": "NC_045512:23063-23065",
     "A570D": "NC_045512:23270-23272",
     "Q613H": "NC_045512:23399-23401",
     "D614G": "NC_045512:23402-23404",
     "A626S": "NC_045512:23438-23441",
     "H655Y": "NC_045512:23525-23527",
     "Q677H": "NC_045512:23591-23593",
+    "P681H": "NC_045512:23603-23605",
     "P681R": "NC_045512:23603-23605",
     "I692V": "NC_045512:23636-23638",
     "A701V": "NC_045512:23663-23665",
     "T716I": "NC_045512:23708-23710",
+    "T732A": "NC_045512:23756-23758",
 }
 
 
